summaryrefslogtreecommitdiffstats
path: root/kcachegrind/kcachegrind/subcost.h
diff options
context:
space:
mode:
Diffstat (limited to 'kcachegrind/kcachegrind/subcost.h')
-rw-r--r--kcachegrind/kcachegrind/subcost.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kcachegrind/kcachegrind/subcost.h b/kcachegrind/kcachegrind/subcost.h
index ab4ac9bc..81692808 100644
--- a/kcachegrind/kcachegrind/subcost.h
+++ b/kcachegrind/kcachegrind/subcost.h
@@ -55,10 +55,10 @@ class SubCost
bool operator>(const SubCost& s) const { return v > s.v; }
/**
* Convert SubCost value into a QString,
* spaced every 3 digits.
*/
- QString pretty();
+ TQString pretty();
uint64 v;
};
@@ -55,10 +55,10 @@ class SubCost
bool operator>(const SubCost& s) const { return v > s.v; }
/**
- * Convert SubCost value into a QString,
+ * Convert SubCost value into a TQString,
* spaced every 3 digits.
*/